/**
 * @author Barbara Pettazzoni
 * @version 1
 *
 * Questa classe rappresenta l'astrazione Auto desiderata dalla
 * concessionaria
 */
public class Auto implements Comparable<Auto>
{
	private String nome, colore;
	private int prezzo, km;
	
	/**
	 * Costruttore della classe. Richiede:
	 * -- Il nome dell'auto
	 * -- Il suo prezzo
	 * -- Il chilometraggio
	 * -- Il colore 
	 */
	public Auto(String nome, int prezzo, int km, String colore)
	{
		this.nome = nome;
		this.prezzo = prezzo;
		this.km = km;
		this.colore = colore;
	}
	
	/**
	 * Metodo che restituisce il nome dell'auto
	 * @return Il nome dell'auto
	 */
	public String getNome()
	{
		return nome;
	}
	
	/**
	 * Metodo che restituisce il colore dell'auto
	 * @return Il colore dell'auto
	 */
	public String getColore()
	{
		return colore;
	}
	
	/**
	 * Metodo che restituisce il chilometraggio dell'auto
	 * @return Il chilometraggio dell'auto
	 */
	public int getChilometraggio()
	{
		return km;
	}
	
	/**
	 * Metodo che restituisce il prezzo dell'auto
	 * @return Il prezzo dell'auto
	 */
	public int getPrezzo()
	{
		return prezzo;
	}
	
	/**
	 * Metodo che stabilisce se un'istanza di Auto  uguale a questa istanza
	 * Osservate che richiede proprio un Auto, e non un Object. Questo  dovuto
	 * al fatto che implementa l'interfaccia Comparable in maniera tipata.
	 * @return true se le istanze sono uguali, false altrimenti
	 */
	public boolean equals(Auto auto)
	{
		return (auto.nome.equals(nome) && auto.colore.equals(colore) && auto.prezzo == prezzo && auto.km == km);
	}
	
	/**
	 * Metodo da implementare dell'interfaccia Compable. Da notare che essendo tipata, si passa un Auto e
	 * non un Object. L'ordinamento  di questo genere:
	 * prezzo > chilometraggio > colore > nome.
	 *@return Un valore maggiore di 0 se l'istanza corrente  "pi grande", minore di 0 se  pi piccola, uguale a 0
	 *				se sono uguali
	 */
	public int compareTo(Auto auto)
	{
		int compare1 = prezzo - auto.prezzo;
		if(compare1 != 0)
			return compare1;
		compare1 = km - auto.km;
		if(compare1 != 0)
			return compare1;
		compare1 = colore.compareTo(auto.colore);
		if(compare1 != 0)
			return compare1;
		return nome.compareTo(auto.nome);
	}
	
	/**
	 * Metodo che fornisce una rappresentazione a String di un'istanza della classe Auto
	 * @return Una rappresentazione stampabile.
	 */
	public String toString()
	{
		return "(Nome: " + nome + ", Prezzo: " + prezzo + ", KM: " + km + ", colore: " + colore + ")";
	}
}